﻿using Hotline.KnowledgeBase;
using Hotline.Repository.SqlSugar.Extensions;
using Hotline.Share.Dtos.Knowledge;
using Hotline.Share.Dtos;
using Hotline.Share.Enums.KnowledgeBase;
using Microsoft.AspNetCore.Mvc;
using Hotline.Share.Dtos.Quality;
using Org.BouncyCastle.Utilities;
using Polly.Caching;
using SqlSugar;

namespace Hotline.Api.Controllers.Bi
{
	public class KnowledgeController : BaseController
	{
		private readonly IKnowledgeRepository _knowledgeRepository;
		public KnowledgeController(IKnowledgeRepository knowledgeRepository) 
		{
			_knowledgeRepository = knowledgeRepository;
		}

		[HttpGet("data_list")]
		public async Task<PagedDto<Object>> DataList([FromQuery] QualityBiDataListDto dto)
		{
			var total = 0;
			var query = _knowledgeRepository.Queryable()
				.Includes(x => x.SourceOrganize)
				.WhereIF(dto.CreationTimeStart.HasValue, x => x.CreationTime >= dto.CreationTimeStart)
				.WhereIF(dto.CreationTimeEnd.HasValue, x => x.CreationTime <= dto.CreationTimeEnd)
				.Select(x => new {
					OrgName = x.SourceOrganize.Name,
					OrgId = x.SourceOrganizeId,
					OrgType = x.SourceOrganize.OrgTypeText,
					AddNum = SqlFunc.MappingColumn(default(int),"SUM(CASE WHEN \"Status\" =3 THEN 1 ELSE 0 END)"),
					DeleteNum = SqlFunc.MappingColumn(default(int), "SUM(CASE WHEN \"IsDeleted\" ='t' THEN 1 ELSE 0 END)"),
					SendBackNum = SqlFunc.MappingColumn(default(int), "SUM(CASE WHEN \"Status\" =5 THEN 1 ELSE 0 END)"),
					PassNum = SqlFunc.MappingColumn(default(int), "SUM(CASE WHEN \"Status\" =3 THEN 1 ELSE 0 END)")
				});
			switch (dto.SortField)
			{
				case 0:
					query = dto.SortRule == 0 ? query.OrderBy(x => x.AddNum) : query.OrderByDescending(x => x.AddNum);
					break;
				case 1:
					query = dto.SortRule == 0 ? query.OrderBy(x => x.DeleteNum) : query.OrderByDescending(x => x.DeleteNum);
					break;
				case 2:
					query = dto.SortRule == 0 ? query.OrderBy(x => x.SendBackNum) : query.OrderByDescending(x => x.SendBackNum);
					break;
				case 3:
					query = dto.SortRule == 0 ? query.OrderBy(x => x.PassNum) : query.OrderByDescending(x => x.PassNum);
					break;
			}
			query.GroupBy(x => x.OrgId);
            var  items = query.ToPageList(dto.PageIndex, dto.PageSize,ref total);
			return new PagedDto<Object>(total, items);
		}
	}
}
